Requirements
------------

The list of package version requirements is available in ``setup.py``, and will be automatically installed along PyDESeq2 when using PyPI.
For reference, the code was tested with python 3.11 and the following package versions::

    - anndata>=0.11.0
    - formulaic>=1.0.2
    - numpy>=2.0.0
    - pandas>=2.2.0
    - scikit-learn>=1.4.0
    - scipy>=1.12.0
    - formulaic-contrasts>=0.2.0
    - matplotlib>=3.9.0

Note that starting from pydeseq2 0.5.3, python 3.10 is no longer supported.
Please don't hesitate to open an issue in case you encounter any problems due to possible deprecations.
